# Copyright 2014 Canonical
# All Rights Reserved

"""Tests module, including some helpers."""

import os

_fixtures_dir = os.path.join(
    os.environ['ROOTDIR'], 'src', 'scopes', 'tests', 'fixtures')


def get_fixture(fname):
    """Get the content of a sample file."""
    full_path = os.path.join(_fixtures_dir, fname)
    with open(full_path, 'rb') as fh:
        return fh.read()


def get_fixture_path(fname):
    """Get the path of a sample file."""
    full_path = os.path.join(_fixtures_dir, fname)
    return full_path


class FakeAmazon(object):
    """Fake Amazon API."""
    def __init__(self, search=None, lookup=None, country="FAKE"):
        self.shop = country
        self.search = get_fixture_path("amazon_" + search) \
            if (search is not None) else None
        if type(lookup) is str:
            self.lookup = get_fixture_path("amazon_" + lookup)
        elif type(lookup) is dict:
            self.lookup = dict((k, get_fixture_path("amazon_" + v))
                               for k, v in lookup.iteritems())
        else:
            lookup = None
        self.history = []

    def __call__(self, *args, **kwargs):
        return self, self.shop

    def ItemSearch(self, **kw):
        """Fake bottleneck object ItemSearch."""
        if self.search is None:
            return '<empty xmlns="empty"/>'
        self.history.append(("ItemSearch", kw))
        return open(self.search).read()

    def ItemLookup(self, ItemId, **kw):
        """Fake bottleneck object ItemLookup."""
        assert self.lookup is not None, "Unexpected ItemLookup of " + ItemId
        if type(self.lookup) is dict:
            assert ItemId in self.lookup, "Unexpected ItemLookup of " + ItemId
        self.history.append(("ItemLookup", dict(kw, ItemId=ItemId)))
        if type(self.lookup) is str:
            return open(self.lookup).read()
        elif type(self.lookup) is dict:
            return open(self.lookup[ItemId]).read()
