# -*- coding: utf8 -*-

# Copyright 2014 Canonical
# All Rights Reserved

""" Test for onlinemusic scope """

from unittest import TestCase

from mock import patch, ANY

from src.scopes import onlinemusic
from src.scopes.tests import get_fixture

CONFIG = {'onlinemusic_server':
          'https://productsearch.ubuntu.com/smartscopes/v1',
          'blacklist': {'DE': ['music-grooveshark.scope']}}


class SearchTestCase(TestCase):
    """The tests for the search part."""

    def test_simple_search(self):
        app = onlinemusic.App(CONFIG)
        with patch.object(onlinemusic, '_get_search') as mock:
            mock.return_value = get_fixture('onlinemusic-results.json')
            response = list(app.search(query=u'foo', locale='en_US',
                                       limit=10, country='US'))

        mock.assert_called_with(ANY, u'foo', u'en_US', ANY, ANY)

        # category
        expect_cat = {'category': app.music_categories[app.CATEGORY_ONLINE]}
        self.assertEqual(response[0], expect_cat)

        # the result
        expect_res = {'result': {
            'cat_id': app.CATEGORY_ONLINE,
            'uri': u'http://produ.com/29',
            'dnd_uri': u'http://produ.com/29',
            'art': 'http://ubuntu.com/350.jpg',
            'artist': 'Various Artists',
            'title': u'Met',
            'real_result': ANY,
            'session': ANY,
            'ssid': ANY
        }}
        self.assertEqual(response[1], expect_res)

    def test_search_from_germany(self):
        app = onlinemusic.App(CONFIG)
        with patch.object(onlinemusic, '_get_search') as mock:
            mock.return_value = get_fixture('onlinemusic-results.json')
            list(app.search(query=u'foo', country='DE',
                            locale='en_US', limit=10))

        # Ensure music-grooveshark.scope is not called
        should_scopes = ['music-soundcloud.scope',
                         'more_suggestions-u1ms.scope']
        mock.assert_called_with(ANY, ANY, ANY, ANY, should_scopes)


class PreviewTestCase(TestCase):
    """Tests for the preview function."""

    def test_ok(self):
        # fake a previous result
        real_res = {
            'metadata': {
                'id': '1234'
            }
        }
        result = {
            'uri': u'https://xyz',
            'dnd_uri': u'https://xyz',
            'art': "http://ubuntu.com/3.jpg",
            'title': u'Test Title',
            'real_result': real_res,
            'session': '1111',
            'ssid': 'xyz'
        }
        app = onlinemusic.App(CONFIG)
        with patch.object(onlinemusic, '_get_preview') as mock:
            mock.return_value = get_fixture('onlinemusic-preview.json')
            response = list(app.preview(result=result, locale='en_US'))

        # the preview
        expect_w1 = {'widget': {
            'id': 'art',
            'type': 'image',
            'source': u'https://one.com/0.jpg'
        }}
        self.assertEqual(response[1], expect_w1)

        expect_w2 = {'widget': {
            'id': 'header',
            'type': 'header',
            'title': u'legacy',
            'subtitle': 'foo'
        }}
        self.assertEqual(response[2], expect_w2)

        expect_w3 = {'widget': {
            'id': 'buttons',
            'type': 'actions',
            'actions': [{'id': 'https://products',
                         'icon': 'u1.svg',
                         'label': 'Download'}]
        }}
        self.assertEqual(response[3], expect_w3)

        expect_w4 = {'widget': {
            'id': 'tracks',
            'type': 'audio',
            'tracks': [{'title': 'Legacy',
                        'source': 'http://t1',
                        'length': 670}]
        }}
        self.assertEqual(response[4], expect_w4)
