# -*- coding: utf8 -*-

# Copyright 2014 Canonical
# All Rights Reserved

""" Test for remotevideos scope """

from unittest import TestCase

from mock import patch, ANY

from src.scopes import remotevideos
from src.scopes.tests import get_fixture

CONFIG = {'remotevideos_server': 'http://videosearch.ubuntu.com/v0'}


class SearchTestCase(TestCase):
    """The tests for the search part."""

    def test_simple_search(self):
        app = remotevideos.App(CONFIG)
        with patch.object(remotevideos, '_get_search') as mock:
            mock.return_value = get_fixture('remotevideos-results.json')
            response = list(app.search(query=u'foo', locale='en_US',
                            limit=10, country='us', platform='phone'))

        mock.assert_called_with(ANY, u'foo', u'phone', u'us')

        # category
        expect_cat = {'category': app.video_categories[app.CATEGORY_ONLINE]}
        self.assertEqual(response[0], expect_cat)
        expect_cat = {'category': app.video_categories[
            app.CATEGORY_MORESUGGESTIONS]}
        self.assertEqual(response[1], expect_cat)

        # the result
        expect_res = {'result': {
            'cat_id': app.CATEGORY_ONLINE,
            'uri': u'https://videosearch.ubuntu.com/v0/xyz',
            'dnd_uri': u'https://videosearch.ubuntu.com/v0/xyz',
            'art': "http://ubuntu.com/38972_big.jpg",
            'title': u'Test Title',
            'details_uri': '',
            'source': u'Test'
        }}
        self.assertEqual(response[2], expect_res)


class PreviewTestCase(TestCase):
    """Tests for the preview function."""

    def test_ok(self):
        # fake a previous result
        result = {
            'uri': u'https://videosearch.ubuntu.com/v0/xyz',
            'dnd_uri': u'https://videosearch.ubuntu.com/v0/xyz',
            'art': "http://ubuntu.com/38972_big.jpg",
            'title': u'Test Title',
            'details_uri': 'http://adsasa.com',
            'source': u'Test'
        }
        app = remotevideos.App(CONFIG)
        with patch.object(remotevideos, '_get_preview') as mock:
            mock.return_value = get_fixture('remotevideos-preview.json')
            response = list(app.preview(result=result, locale='en_US'))

        # got the info as it should
        mock.assert_called_with('http://adsasa.com')

        # the preview
        expect_w1 = {'widget': {
            'id': 'video',
            'type': 'video',
            'source': u'https://videosearch.ubuntu.com/v0/xyz',
            'screenshot': 'http://s2.n.net/DoAQj.jpg'
        }}
        self.assertEqual(response[1], expect_w1)

        expect_w2 = {'widget': {
            'id': 'header',
            'type': 'header',
            'title': u'Test Title',
            'subtitle': u'Dailymotion'
        }}
        self.assertEqual(response[2], expect_w2)

        expect_w3 = {'widget': {
            'id': 'buttons',
            'type': 'actions',
            'actions': [{
                        'id': 'play',
                        'label': 'Play',
                        'uri': 'https://videosearch.ubuntu.com/v0/xyz'
                        }]
        }}
        self.assertEqual(response[3], expect_w3)

        expect_w4 = {'widget': {
            'id': 'description',
            'type': 'text',
            'text': 'long text'
        }}
        self.assertEqual(response[4], expect_w4)
