#!/usr/bin/python3

import re
import sys

from urllib import request

import bs4

URL_BASE = "http://docs.aws.amazon.com/AWSECommerceService/latest/DG/"
LISTING = "APPNDX_SortValuesArticle.html"

def get_sort_values(page):
    """Get sort values from a specific page."""
    url = URL_BASE + page
    html = request.urlopen(url).read()
    soup = bs4.BeautifulSoup(html)

    # first section is the topics menu, let's get the rest
    sections = soup.find_all('div', 'section')
    descriptions = {}
    sortparams = {}
    for section in sections[1:]:
        title = section.find('h2').text
        department = title.split(':')[1].strip()
        info = section.find('div', 'informaltable')
        if info is not None:
            sortparams[department] = parameters = []
            for value, descrip in info.find_all('tr')[1:]:
                value = value.text.strip()
                descrip = descrip.text.strip()
                parameters.append(value)
                descriptions[value] = descrip
    return sortparams, descriptions


def main(dest_file):
    """Main entry point."""
    # get the listing
    url = URL_BASE + LISTING
    html = request.urlopen(url).read()
    soup = bs4.BeautifulSoup(html)
    links = soup.find_all('a', 'link')

    # get the info for each page
    results = {}
    all_descriptions = {}
    for link in links:
        m = re.match("(\w+) Sort Values", link.text)
        if m is not None:
            shop = m.groups()[0]
            page = link['href']
            print("Found page for {}: {}".format(shop, page))
            params, descripts = get_sort_values(page)
            results[shop] = params
            all_descriptions.update(descripts)

    # store it all in a config file
    with open(dest_file, 'wt', encoding='utf8') as fh:
        for shop, info in sorted(results.items()):
            fh.write("{}:\n".format(shop))
            for depart, params in sorted(info.items()):
                fh.write("    {}: [{}]\n".format(depart, ", ".join(params)))
            fh.write("\n")

        fh.write("__descriptions__:\n")
        for param, text in sorted(all_descriptions.items()):
            # remove linebreaks with their identation
            text = re.sub("\n *", " ", text)
            fh.write('    {}: "{}"\n'.format(param, text))


if __name__ == "__main__":
    if len(sys.argv) != 2:
        print("Usage: {} <config_file.yaml>".format(sys.argv[0]))
        exit()

    main(sys.argv[1])
